This repository contains the TsAssure python package. 

The package provides systematic time-series feature extraction by calculating the correlation among different time-series data points and extracting the meaningful features. In this context, the term time series is interpreted in the broadest possible sense, such that any type of sampled data or even event sequences can be characterized.

The file is on github as well: https://github.com/shadi-attarha/tsassure-feature-extraction

The example can be find in quick_start.rst

